summaryrefslogtreecommitdiff
path: root/oox/inc/oox/drawingml/chart/converterbase.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'oox/inc/oox/drawingml/chart/converterbase.hxx')
-rw-r--r--oox/inc/oox/drawingml/chart/converterbase.hxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/oox/inc/oox/drawingml/chart/converterbase.hxx b/oox/inc/oox/drawingml/chart/converterbase.hxx
index aec646d4c610..12c6c2294b32 100644
--- a/oox/inc/oox/drawingml/chart/converterbase.hxx
+++ b/oox/inc/oox/drawingml/chart/converterbase.hxx
@@ -138,9 +138,10 @@ public:
OOXML layout model. Returns true, if returned rectangle is valid. */
bool calcAbsRectangle( ::com::sun::star::awt::Rectangle& orRect ) const;
- /** Tries to set the position from the contained OOXML layout model.
- Returns true, if a manual position could be calculated. */
+ /** Tries to set the position and size from the contained OOXML layout model.
+ Returns true, if a manual position and size could be calculated. */
bool convertFromModel( PropertySet& rPropSet );
+
/** Tries to set the position from the contained OOXML layout model.
Returns true, if a manual position could be calculated. */
bool convertFromModel(